==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebPivotConfigurationChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPivotConfigurationChangedEventArgsDetailDescriptionMetadata } from "./WebPivotConfigurationChangedEventArgsDetailDescriptionMetadata";
import { WebPivotConfigurationChangedEventArgsDescription } from "./WebPivotConfigurationChangedEventArgsDescription";
/**
 * @hidden
 */
var WebPivotConfigurationChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPivotConfigurationChangedEventArgsDescriptionMetadata, _super);
    function WebPivotConfigurationChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPivotConfigurationChangedEventArgsDescriptionMetadata.b = function (a) {
        if (WebPivotConfigurationChangedEventArgsDescriptionMetadata.a == null) {
            WebPivotConfigurationChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPivotConfigurationChangedEventArgsDescriptionMetadata.c(WebPivotConfigurationChangedEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebPivotConfigurationChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebPivotConfigurationChangedEventArgsDescriptionMetadata.a);
        WebPivotConfigurationChangedEventArgsDetailDescriptionMetadata.d(a);
    };
    WebPivotConfigurationChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PivotConfigurationChangedEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebPivotConfigurationChangedEventArgsDetail");
    };
    WebPivotConfigurationChangedEventArgsDescriptionMetadata.d = function (a) {
        WebPivotConfigurationChangedEventArgsDescriptionMetadata.b(a);
        a.ad("WebPivotConfigurationChangedEventArgs", function () { return new WebPivotConfigurationChangedEventArgsDescription(); });
        a.ac("WebPivotConfigurationChangedEventArgs", WebPivotConfigurationChangedEventArgsDescriptionMetadata.a);
    };
    WebPivotConfigurationChangedEventArgsDescriptionMetadata.$t = markType(WebPivotConfigurationChangedEventArgsDescriptionMetadata, 'WebPivotConfigurationChangedEventArgsDescriptionMetadata');
    WebPivotConfigurationChangedEventArgsDescriptionMetadata.a = null;
    return WebPivotConfigurationChangedEventArgsDescriptionMetadata;
}(Base));
export { WebPivotConfigurationChangedEventArgsDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/WebPivotConfigurationChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPivotConfigurationChangedEventArgsDetailDescriptionMetadata } from "./WebPivotConfigurationChangedEventArgsDetailDescriptionMetadata";
import { WebPivotConfigurationChangedEventArgsDescription } from "./WebPivotConfigurationChangedEventArgsDescription";
/**
 * @hidden
 */
var WebPivotConfigurationChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPivotConfigurationChangedEventArgsDescriptionMetadata, _super);
    function WebPivotConfigurationChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPivotConfigurationChangedEventArgsDescriptionMetadata.b = function (a) {
        if (WebPivotConfigurationChangedEventArgsDescriptionMetadata.a == null) {
            WebPivotConfigurationChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPivotConfigurationChangedEventArgsDescriptionMetadata.c(WebPivotConfigurationChangedEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebPivotConfigurationChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebPivotConfigurationChangedEventArgsDescriptionMetadata.a);
        WebPivotConfigurationChangedEventArgsDetailDescriptionMetadata.d(a);
    };
    WebPivotConfigurationChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PivotConfigurationChangedEventArgs");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__marshalByValue", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebPivotConfigurationChangedEventArgsDetail");
    };
    WebPivotConfigurationChangedEventArgsDescriptionMetadata.d = function (a) {
        WebPivotConfigurationChangedEventArgsDescriptionMetadata.b(a);
        a.ae("WebPivotConfigurationChangedEventArgs", function () { return new WebPivotConfigurationChangedEventArgsDescription(); });
        a.ad("WebPivotConfigurationChangedEventArgs", WebPivotConfigurationChangedEventArgsDescriptionMetadata.a);
    };
    WebPivotConfigurationChangedEventArgsDescriptionMetadata.$t = markType(WebPivotConfigurationChangedEventArgsDescriptionMetadata, 'WebPivotConfigurationChangedEventArgsDescriptionMetadata');
    WebPivotConfigurationChangedEventArgsDescriptionMetadata.a = null;
    return WebPivotConfigurationChangedEventArgsDescriptionMetadata;
}(Base));
export { WebPivotConfigurationChangedEventArgsDescriptionMetadata };
